=begin rdoc
ruby

Ulrich Mutze, www.ulrichmutze.de

Studying the conserved quantities in 2-dimensional Kepler motion

This is free software. It comes without any warranty.
Please contact the author to report problems or to
ask questions.
=end

require 'graph'
require 'kepler_2d'

include AppMath

###################### input area ########################################

# selection parameter, presently only sel = 1
# See explanations in the corresponding 'when' statement line
sel = 1

################### end of input area ####################################

case sel

when 1 # Test of class Kep2D
  R.prec = 9

# These three numbers give all reals of the application he right type
  pi = R.pi
  zero = R.c0
  r = R.c 5
  g = R.c 10
# No symbol R needed in what follows  

  puts "r.class = " + r.class.to_s
  puts "pi.class = " + pi.class.to_s

  vr = (g/r).sqrt
  v = R2.new(zero,vr)
  p = R2.new(r,zero)
  t_tot = pi*r*2/vr
  omega = (pi * 2)/t_tot
  n = 100
  dt = t_tot/(n-1)

  sys = Kep2D.new(p,v,g)
  e0 = sys.energy
  am0 = sys.ang_mom
  le0 = sys.lenz

  arr_x = Array.new
  arr_y = Array.new
  arr_e = Array.new
  arr_am = Array.new
  arr_le_x = Array.new
  arr_le_y = Array.new
  arr_i = Array.new

  for i in 1..n
    sys.step!(dt)
    alpha = sys.get_t * omega
    arr_x << (sys.get_x - r * alpha.cos ).to_f
    arr_y << (sys.get_y - r * alpha.sin).to_f
    arr_e << (sys.energy - e0).to_f
    arr_am << (sys.ang_mom - am0).to_f
    arr_le_x << (sys.lenz - le0).x.to_f
    arr_le_y << (sys.lenz - le0).y.to_f
    arr_i << i.to_f
  end

  root = TkRoot.new{
    title 'Test of class Kep2D'
  }
 
  nx=1200
  ny=700
  
  px = 3
  py = 2
 
  grs = Graphs.new(root,px,py,nx,ny)
  
  gr1 = grs.at(0,0)
  gr2 = grs.at(0,1)
  gr3 = grs.at(0,2)
  gr4 = grs.at(1,0)
  gr5 = grs.at(1,1)
  gr6 = grs.at(1,2)
  
  gr1.grid_color = 'white'
  gr1.bgr_color = 'lightgray'
  gr2.grid_color = 'white'
  gr2.bgr_color = 'lightgray'
  gr3.grid_color = 'white'
  gr3.bgr_color = 'lightgray'
  
  gr1.draw(arr_i, arr_le_x, 'red')
  gr2.draw(arr_i, arr_le_y, 'cyan')
  gr3.draw(arr_le_x, arr_le_y, 'blue')
  gr4.draw(arr_i, arr_e, 'white')
  gr5.draw(arr_i, arr_am, 'magenta')
  
  Tk.mainloop
  
else 

  puts "unvalid selection, nothing to do"

end 
