=begin rdoc
ruby

Ulrich Mutze, www.ulrichmutze.de

Simple test application for real and complex numbers and for graphical
representation of curves.

This is free software. It comes without any warranty.
Please contact the author to report problems or to
ask questions.
=end

=begin
2008-11-01
Experimentation with BigDecimal
The most useful thing to do seems to create a class of reals 
of arbitrary precission.
Unfortunately many functions are implemented by the
most simple power series expansion. These have to reimplemented to become
useful.
I should do this! action!
UM 2008-11-04: essentially done! For final testing I should have a
graphical test facility which I'm developing presently
Aritmetics seems to be pretty fast
Add the case R=Float for @@dig=0 (or <= 0 ?) action! done
perhaps 10^x as primary and e^x=exp(x) as derived from it, could be faster
and more accurate action! done
=end 

require 'graph'
require 'cnum'

include AppMath


###################### input area ########################################
# selection parameter
# See explanations in the corresponding 'when' statement line
sel = 1

################### end of input area ####################################
case sel
when 1 # Test of classes Graphs and R and function objects

  root = TkRoot.new{
    title 'Test of classes Graphs and R and function objects'
  }
  
  R.prec = 12
  p0 = R.prec
  puts "R.prec = " + R.prec.to_s
  
  nx=1200
  ny=700
  
  px = 3
  py = 2
 
  grs = Graphs.new(root,px,py,nx,ny)
  
  gr1 = grs.at(0,0)
  gr2 = grs.at(0,1)
  gr3 = grs.at(0,2)
  gr4 = grs.at(1,0)
  gr5 = grs.at(1,1)
  gr6 = grs.at(1,2)

  n=50
  auto = true
  xl=R.c(8.5)
  ivx=Iv.new(-xl,xl)
  gr1.set_size_x!(ivx)
  gr2.set_size_x!(ivx)
  gr3.set_size_x!(ivx)
  gr4.set_size_x!(ivx*2)
  gr5.set_size_x!(ivx*2)
  gr6.set_size_x!(ivx)
  gr1.draw_func(Exp.new,n,'white',auto)
  gr2.draw_func(Sin.new,n,'white',auto)
  gr3.draw_func(Cos.new,n,'white',auto)
  gr4.draw_func(Log.new,n,'white',auto)
  gr5.draw_func(Erfc.new,n,'white',auto)
  gr6.draw_func(ArcTan.new,n,'white',auto) 
  
 #R.prec = 1
  prec2=1 # The algorithms for the functions work even for 
  # prec = 1. Of course, the x-values have to be taken from
  auto = false
  gr1.text_color = gr1.bgr_color
  gr2.text_color = gr2.bgr_color
  gr3.text_color = gr3.bgr_color
  gr4.text_color = gr4.bgr_color
  gr5.text_color = gr5.bgr_color
  gr6.text_color = gr6.bgr_color
  gr1.draw_func(Exp.new(prec2),n,'red',auto)
  gr2.draw_func(Sin.new(prec2),n,'red',auto)
  gr3.draw_func(Cos.new(prec2),n,'red',auto)
  gr4.draw_func(Log.new(prec2),n,'red',auto)
  gr5.draw_func(Erfc.new(prec2),n,'red',auto)
  gr6.draw_func(ArcTan.new(prec2),n,'red',auto)

  Tk.mainloop
# all combinations of the two R.prec settings work
# (in each case three options dig = -1, 0, 20
# However, only the case 0, 2 really shows how the limited accuracy curves
# (dig = 2) fit to the accurate ones (dig = 0). 


when 2 # test of R.test, changing the accuracy from call to call
  count = R.c0
  s = R.c0
  verbose = false
 # cases = [-1]
 # param = [137]
  cases = [0,20,40]
  param = [0, 137]
  cases.each{ |x|
    param.each{ |y|
      R.prec = x
      d = R.test(y,verbose)
      s += d
      count += 1
    }
  }
  res = s/count
  puts "res = " + res.to_s

when 3 # simple computations with default accuracy
  x = R.new(-100)
  y = x.exp
  puts "y="+y.to_s

  a = R.new(250)
  d = a.sin**2 + a.cos**2 - 1
  puts d.to_s
  
when 4 # testing complex arithmetics and functions
  dig = 100
  R.prec = dig
  C.test(137,false)
  
when 5 # testing input formats
  R.prec = "F"
  x = [R.c("3.45E-45"),  R.c(2),  R.c(1.25e13),  R.c("4000.1e-1")]
  x.each{ |x|
    puts " x = #{x}"
  }
  
when 6 # testing R.new
  R.prec = 6
  x = R.new("-6.6666666666666666")
  puts "x=" + x.to_s
  R.prec = 40
  i = 10000000
  j = 123456789
  a = R.new(i * j)
  b = R.new(1e-23)
  c = R.new("-117.07e99")
  R.prec = 100 # same as R.prec = 1e2
  d = R.new(1e66)
  e = R.new("1E666")
  arr = [a,b,c,d,e]
  arr.each{ |x|
    x.prn("#{x}")
  }

else 
  puts "unvalid selection, nothing to do"

end 
